summaryrefslogtreecommitdiff
path: root/gcc/langhooks.h
diff options
context:
space:
mode:
authorkazu <kazu@138bc75d-0d04-0410-961f-82ee72b054a4>2002-09-22 14:09:34 +0000
committerkazu <kazu@138bc75d-0d04-0410-961f-82ee72b054a4>2002-09-22 14:09:34 +0000
commit6ef828f9e997f2a593360aa6ce158d9f5ae739a0 (patch)
treed2db7ebbe3f404f7fa5e30b7ecf4ac4675f5b518 /gcc/langhooks.h
parent43e00fc9fcdb8cf219d4f9cf9ff1d45dbcbadeee (diff)
downloadgcc-6ef828f9e997f2a593360aa6ce158d9f5ae739a0.tar.gz
* dbxout.c: Follow spelling conventions.
* defaults.h: Likewise. * df.c: Likewise. * diagnostic.h: Likewise. * doloop.c: Likewise. * dwarf2out.c: Likewise. * dwarfout.c: Likewise. * emit-rtl.c: Likewise. * except.c: Likewise. * explow.c: Likewise. * expmed.c: Likewise. * expr.c: Likewise. * expr.h: Likewise. * flags.h: Likewise. * flow.c: Likewise. * fold-const.c: Likewise. * function.c: Likewise. * function.h: Likewise. * gcc.c: Likewise. * gcov-io.h: Likewise. * gcov.c: Likewise. * gcse.c: Likewise. * genattrtab.c: Likewise. * genconfig.c: Likewise. * genrecog.c: Likewise. * ggc-page.c: Likewise. * ggc.h: Likewise. * global.c: Likewise. * gthr-win32.h: Likewise. * integrate.c: Likewise. * jump.c: Likewise. * langhooks.c: Likewise. * langhooks.h: Likewise. * line-map.h: Likewise. * local-alloc.c: Likewise. * longlong.h: Likewise. * loop.c: Likewise. * loop.h: Likewise. git-svn-id: svn+ssh://gcc.gnu.org/svn/gcc/trunk@57406 138bc75d-0d04-0410-961f-82ee72b054a4
Diffstat (limited to 'gcc/langhooks.h')
-rw-r--r--gcc/langhooks.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/gcc/langhooks.h b/gcc/langhooks.h
index 993d970ad58..0518afed0ef 100644
--- a/gcc/langhooks.h
+++ b/gcc/langhooks.h
@@ -78,7 +78,7 @@ struct lang_hooks_for_functions
struct lang_hooks_for_tree_dump
{
/* Dump language-specific parts of tree nodes. Returns non-zero if it
does not want the usual dumping of the second argument. */
int (*dump_tree) PARAMS ((void *, tree));
@@ -142,7 +142,7 @@ struct lang_hooks_for_decls
FUNCTIONBODY -- nonzero if this level is the body of a function. */
tree (*poplevel) PARAMS ((int, int, int));
/* Returns non-zero if we are in the global binding level. Ada
returns -1 for an undocumented reason used in stor-layout.c. */
int (*global_bindings_p) PARAMS ((void));
@@ -201,7 +201,7 @@ struct lang_hooks
Should return zero unless the compiler back-end does not need to
be initialized, such as with the -E option.
- If errorcount is non-zero after this call the compiler exits
+ If errorcount is nonzero after this call the compiler exits
immediately and the finish hook is not called. */
bool (*post_options) PARAMS ((void));
@@ -216,7 +216,7 @@ struct lang_hooks
/* Called at the end of compilation, as a finalizer. */
void (*finish) PARAMS ((void));
/* Parses the entire file. The argument is non-zero to cause bison
parsers to dump debugging information during parsing. */
void (*parse_file) PARAMS ((int));
@@ -78,7 +78,7 @@ struct lang_hooks_for_functions
struct lang_hooks_for_tree_dump
{
- /* Dump language-specific parts of tree nodes. Returns non-zero if it
+ /* Dump language-specific parts of tree nodes. Returns nonzero if it
does not want the usual dumping of the second argument. */
int (*dump_tree) PARAMS ((void *, tree));
@@ -142,7 +142,7 @@ struct lang_hooks_for_decls
FUNCTIONBODY -- nonzero if this level is the body of a function. */
tree (*poplevel) PARAMS ((int, int, int));
- /* Returns non-zero if we are in the global binding level. Ada
+ /* Returns nonzero if we are in the global binding level. Ada
returns -1 for an undocumented reason used in stor-layout.c. */
int (*global_bindings_p) PARAMS ((void));
@@ -216,7 +216,7 @@ struct lang_hooks
/* Called at the end of compilation, as a finalizer. */
void (*finish) PARAMS ((void));
- /* Parses the entire file. The argument is non-zero to cause bison
+ /* Parses the entire file. The argument is nonzero to cause bison
parsers to dump debugging information during parsing. */
void (*parse_file) PARAMS ((int));